from PyQt5.QtXml import (
    QDomAttr,
    QDomCDATASection,
    QDomCharacterData,
    QDomComment,
    QDomDocument,
    QDomDocumentFragment,
    QDomDocumentType,
    QDomElement,
    QDomEntity,
    QDomEntityReference,
    QDomImplementation,
    QDomNamedNodeMap,
    QDomNode,
    QDomNodeList,
    QDomNotation,
    QDomProcessingInstruction,
    QDomText,
    QXmlAttributes,
    QXmlContentHandler,
    QXmlDTDHandler,
    QXmlDeclHandler,
    QXmlDefaultHandler,
    QXmlEntityResolver,
    QXmlErrorHandler,
    QXmlInputSource,
    QXmlLexicalHandler,
    QXmlLocator,
    QXmlNamespaceSupport,
    QXmlParseException,
    QXmlReader,
    QXmlSimpleReader,
)